.. include:: README.rst

.. toctree::
   :hidden:

   Home<README>


.. toctree::
   :hidden:

   API Reference<generated_api/darts>


.. toctree::
   :hidden:

   Examples<examples>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
